﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using DividendGraph.Manager.Interface;
using DividendGraph.Types;

namespace DividendGraph.Manager.Concrete
{
    public class TestRepository : IRepository
    {
        private Random _random;

        public TestRepository()
        {
            _random = new Random((int)DateTime.Now.Ticks);
        }

        #region IRepository Members

        public Types.Dividend GetById(string ticker)
        {
            return new Dividend(DateTime.Now, (Decimal)_random.NextDouble());
        }

        public Types.Dividend GetByMonth(string ticker, int month, int year)
        {
            return new Dividend(DateTime.Parse(month + "-1-" + year), (Decimal)_random.NextDouble());
        }

        public List<Types.Dividend> GetByRange(string ticker, Types.Range range)
        {
            List<Dividend> dividendList = new List<Dividend>();

            // Simulate data from endDate to startDate.
            DateTime startDate = new DateTime(range.StartYear, range.StartMonth, 1);
            DateTime endDate = new DateTime(range.EndYear, range.EndMonth, 1);
            TimeSpan span = endDate - startDate;

            while (span.Days > 0)
            {
                DateTime currentDate = endDate - span;

                dividendList.Add(new Dividend(currentDate, (Decimal)_random.NextDouble()));

                // Reduce the span difference, incrementing the date.
                span -= TimeSpan.FromDays(30);
            }

            return dividendList;
        }

        #endregion
    }
}
