﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.Net;
using DividendGraph.Manager.Interface;
using DividendGraph.Types;

namespace DividendGraph.Manager.Concrete
{
    public class YahooRepository : IRepository
    {
        private string _url = "http://ichart.finance.yahoo.com/table.csv?s=";

        private Stream GetURLStream(string strURL)
        {
            System.Net.WebRequest objRequest;
            System.Net.WebResponse objResponse = null;
            Stream objStreamReceive;
            
            try
            {
                objRequest = System.Net.WebRequest.Create(strURL);
                objRequest.Timeout = 5000;
                // objRequest.Proxy = new WebProxy("my.proxyserver.com", 8080);
                // objRequest.Proxy.Credentials = new NetworkCredential("username", "password");

                objResponse = objRequest.GetResponse();
                objStreamReceive = objResponse.GetResponseStream();

                return objStreamReceive;
            }
            catch
            {
                if (objResponse != null)
                {
                    objResponse.Close();
                }

                throw;
            }
        }

        private Dividend ParseDividendFromCSV(string line)
        {
            Dividend dividend = new Dividend();

            // Parse dividend information: XXXX-XX-XX,X.XXX
            char[] seps = new char[] { ',' };
            string[] parts = line.Split(seps);

            if (parts.Length == 2)
            {
                try
                {
                    dividend.Date = DateTime.Parse(parts[0]);
                    dividend.Price = Decimal.Parse(parts[1]);

                    return dividend;
                }
                catch
                {
                }
            }

            return null;
        }

        #region IRepository Members

        public Dividend GetById(string ticker)
        {
            return GetByMonth(ticker, DateTime.Now.Month, DateTime.Now.Year);
        }

        public Dividend GetByMonth(string ticker, int month, int year)
        {
            Dividend dividend = new Dividend();

            // Format the URL to read stock data from service.
            string url = _url;
            url += ticker;
            url += "&a=" + month + "&b=1&c=" + year + "&d=" + month + "&e=" + DateTime.DaysInMonth(year, month) + "&f=" + year + "&g=v";

            // Read the data from the stream.
            using (Stream stream = GetURLStream(url))
            {
                using (StreamReader reader = new StreamReader(stream))
                {
                    // Skip header line.
                    reader.ReadLine();

                    // Parse the dividend.
                    dividend = ParseDividendFromCSV(reader.ReadLine());
                }
            }

            return dividend;
        }

        public List<Dividend> GetByRange(string ticker, Range range)
        {
            List<Dividend> dividendList = new List<Dividend>();

            // Format the URL to read stock data from service.
            string url = _url;
            url += ticker;
            url += "&a=" + range.StartMonth + "&b=1&c=" + range.StartYear + "&d=" + range.EndMonth + "&e=" + DateTime.DaysInMonth(range.EndYear, range.EndMonth) + "&f=" + range.EndYear + "&g=v";

            // Read the data from the stream.
            using (Stream stream = GetURLStream(url))
            {
                using (StreamReader reader = new StreamReader(stream))
                {
                    // Skip header line.
                    reader.ReadLine();

                    while (!reader.EndOfStream)
                    {
                        // Parse the dividend.
                        Dividend dividend = ParseDividendFromCSV(reader.ReadLine());

                        if (dividend != null)
                        {
                            dividendList.Add(dividend);
                        }
                    }
                }
            }

            return dividendList;
        }

        #endregion
    }
}
