﻿using System;
using System.Windows.Controls;
using System.Windows.Controls.DataVisualization.Charting;
using DividendGraph.ServiceReference1;

namespace DividendGraph
{
    public partial class MainPage : UserControl
    {
        private LineSeries _ctlGraph;
        private DividendServiceClient _dividendService = new DividendServiceClient();

        public MainPage()
        {
            InitializeComponent();

            // Setup an event callback for the web service completed method. We'll populate the UI upon this event.
            _dividendService.GetDividendsCompleted += new EventHandler<GetDividendsCompletedEventArgs>(_dividendService_GetDividendsCompleted);

            // Initialize a ticker symbol of Bank of America.
            txtTicker.Text = "BAC";

            // Populate the Silverlight graph chart.
            BindGraph();
        }

        void _dividendService_GetDividendsCompleted(object sender, GetDividendsCompletedEventArgs e)
        {
            // Web service method callback event.
            _ctlGraph = (LineSeries)ctlChart.Series[0];
            _ctlGraph.ItemsSource = e.Result;
        }

        private void txtTicker_TextChanged(object sender, TextChangedEventArgs e)
        {
            // When the ticker text has changed and has 3 characters, update the Silverlight graph chart.
            if (txtTicker.Text.Length == 3)
            {
                BindGraph();
            }
        }

        private void chkTestData_Checked(object sender, System.Windows.RoutedEventArgs e)
        {
            BindGraph();
        }

        private void BindGraph()
        {
            _dividendService.GetDividendsAsync(txtTicker.Text, chkTestData.IsChecked.GetValueOrDefault());
        }
    }
}
